@@ -2,6 +2,7 @@
 from .game_guess_operator import __plugin_meta__ as GUESS_META
 from .misc_operator_birthday import __plugin_meta__ as BIRTHDAY_META
 from .misc_monster_siren import __plugin_meta__ as SIREN_META
+from .tool_announce_push import __plugin_meta__ as ANNOUNCE_META
 from .tool_operator_info import __plugin_meta__ as INFO_META
 from .tool_open_recruitment import __plugin_meta__ as RECRUIT_META
 from .tool_sanity_notify import __plugin_meta__ as SAN_META
@@ -17,6 +18,7 @@ HELP_DATAS = [
     GUESS_META,
     BIRTHDAY_META,
     SIREN_META,
+    ANNOUNCE_META,
     INFO_META,
     RECRUIT_META,
     SAN_META,
